<?php

$filename = 'c_leitura.php';

$dados = "C#";

if (!file_exists($filename)) {
    header("Location: error.php");
    exit;
}

include 'c_leitura.php';
if (!empty($_GET) AND ( empty($_GET['login']) )) {
    echo "V#";
}
require_once("db.php");

$safe_user = mysql_real_escape_string($_GET['login']);
$safe_pass = md5(mysql_real_escape_string($_GET['passwd']));

$query = "SELECT * FROM cliente WHERE cpf = '" . $safe_user . "'";

$resultCliente = mysql_query($query) or die(mysql_error());

// Verifica se a consulta retornou resultados antes de tentar acessar os dados
if ($resultCliente && mysql_num_rows($resultCliente) > 0) {
    // Obter a primeira linha do resultado
    $rowCliente = mysql_fetch_assoc($resultCliente);
    // Saída do nome do cliente
    // echo "cliente nome: " . $rowCliente['id'];

    $query = "SELECT * FROM user WHERE id = '" . $rowCliente['user_id'] . "' ";


    $result = mysql_query($query) or die(mysql_error());

    if (mysql_num_rows($result) == 0) {
        echo "NC#";
    } else {

        $rowDono = mysql_fetch_array($result);
        // echo $rowDono['nome'];
        $resultUser = mysql_query("SELECT nome FROM ponto WHERE  "
                . " ponto.id_apoio = '" . $rowDono['id'] . "' "
                . " AND status = 1"
                . " ORDER BY nome ASC");

                while ($rowUser = mysql_fetch_array($resultUser)) {

                    $dados = $dados . $rowUser['nome'] . "#";
                }
                 echo $dados;

        
    }
} else {
    echo "Nenhum cliente encontrado para o CPF fornecido.";
}



?>
